Command Reference
=================

Running Cicada programs on multiple machines is easier with the following:

.. _cicada:

cicada
------

.. argparse::
    :module: cicada.cli.main
    :func: parser
    :prog: cicada

.. _cicada-perf:

cicada-perf
-----------

.. argparse::
    :module: cicada.cli.perf
    :func: parser
    :prog: cicada-perf

